==> react-molecule-stepper-2.2.0.tgz: package/lib/Step/DefaultStep.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
import PropTypes from 'prop-types';
import cx from 'classnames';
import { naturalNumber } from '../prop-types.js';
import { ALIGNMENT, DESIGN } from '../settings.js';
import { BASE_CLASS_STEP, getLabel, getIcon } from './settings.js';
import { jsx as _jsx } from "react/jsx-runtime";
import { Fragment as _Fragment } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";

var DefaultStep = function DefaultStep(_ref) {
  var alignment = _ref.alignment,
      design = _ref.design,
      label = _ref.label,
      step = _ref.step,
      steps = _ref.steps,
      current = _ref.current,
      visited = _ref.visited,
      icon = _ref.icon,
      visitedIcon = _ref.visitedIcon,
      currentIcon = _ref.currentIcon;
  var resultingIcon = getIcon({
    design: design,
    visited: visited,
    current: current,
    step: step,
    icon: icon,
    visitedIcon: visitedIcon,
    currentIcon: currentIcon
  });
  return /*#__PURE__*/_jsxs(_Fragment, {
    children: [/*#__PURE__*/_jsx("div", {
      className: cx(BASE_CLASS_STEP + "Icon"),
      children: resultingIcon
    }), /*#__PURE__*/_jsx("div", _extends({
      className: cx(BASE_CLASS_STEP + "Label")
    }, design === DESIGN.COMPRESSED && current && alignment === ALIGNMENT.HORIZONTAL && {
      style: {
        marginLeft: "calc(-" + (step - 1) * 100 + "% - " + (step - 1) * 8 + "px)"
      }
    }, {
      children: getLabel({
        steps: steps,
        step: step,
        design: design,
        label: label,
        current: current
      })
    }))]
  });
};

DefaultStep.displayName = 'DefaultStep';
export default DefaultStep;

==> react-molecule-stepper-2.3.0.tgz: package/lib/Step/DefaultStep.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
import cx from 'classnames';
import PropTypes from 'prop-types';
import { naturalNumber } from '../prop-types.js';
import { ALIGNMENT, DESIGN } from '../settings.js';
import { BASE_CLASS_STEP, getIcon, getLabel } from './settings.js';
import { jsx as _jsx } from "react/jsx-runtime";
import { Fragment as _Fragment } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";

var DefaultStep = function DefaultStep(_ref) {
  var alignment = _ref.alignment,
      design = _ref.design,
      label = _ref.label,
      step = _ref.step,
      steps = _ref.steps,
      current = _ref.current,
      visited = _ref.visited,
      icon = _ref.icon,
      visitedIcon = _ref.visitedIcon,
      currentIcon = _ref.currentIcon;
  var resultingIcon = getIcon({
    design: design,
    visited: visited,
    current: current,
    step: step,
    icon: icon,
    visitedIcon: visitedIcon,
    currentIcon: currentIcon
  });
  return /*#__PURE__*/_jsxs(_Fragment, {
    children: [/*#__PURE__*/_jsx("div", {
      className: cx(BASE_CLASS_STEP + "Icon"),
      children: resultingIcon
    }), /*#__PURE__*/_jsx("div", _extends({
      className: cx(BASE_CLASS_STEP + "Label")
    }, design === DESIGN.COMPRESSED && current && alignment === ALIGNMENT.HORIZONTAL && {
      style: {
        marginLeft: "calc(-" + (step - 1) * 100 + "% - " + (step - 1) * 8 + "px)"
      }
    }, {
      children: getLabel({
        steps: steps,
        step: step,
        design: design,
        label: label,
        current: current
      })
    }))]
  });
};

DefaultStep.displayName = 'DefaultStep';
export default DefaultStep;
